@@ -16,11 +16,11 @@ cat("\n")
 pick <- menu(file.menu, title = " << Separator type and Decimal type >> ")
 if (pick == 1){
   cat("\n\n")
-        cat("\nEnter Data file name(without file extension of .csv)\n")
-        Single.file <-readline()
-        Single.file<-paste(Single.file,".csv",sep="")
-        cnames<-c("time","assay (%)")
-        Singledata<-read.csv(Single.file,header=TRUE,row.names=NULL,col.names=cnames, sep=",",dec=".")
+        ### cat("\nEnter Data file name(without file extension of .csv)\n")
+        ### Single.file <-readline()
+        ### Single.file<-paste(Single.file,".csv",sep="")
+        cnames<-c("Time","Assay")
+        Singledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=",",dec=".")
         Singledata<-edit(Singledata)
         Singledata<- na.omit(Singledata)
         cat("\n\n")
@@ -35,11 +35,11 @@ if (pick == 1){
  else {
   if (pick == 2){
   cat("\n\n")
-        cat("\nEnter Data file name(without file extension of.csv)\n")
-        Single.file <-readline()
-        Single.file<-paste(Single.file,".csv",sep="")
-        cnames<-c("time","assay (%)")
-        Singledata<-read.csv(Single.file,header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=",")
+        ### cat("\nEnter Data file name(without file extension of.csv)\n")
+        ### Single.file <-readline()
+        ### Single.file<-paste(Single.file,".csv",sep="")
+        cnames<-c("Time","Assay")
+        Singledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=",")
         Singledata<-edit(Singledata)
         Singledata<- na.omit(Singledata)
         cat("\n\n")
@@ -53,11 +53,11 @@ if (pick == 1){
  else {
   if (pick == 3){
   cat("\n\n")
-        cat("\nEnter Data file name(without file extension of.csv)\n")
-        Single.file <-readline()
-        Single.file<-paste(Single.file,".csv",sep="")
-        cnames<-c("time","assay (%)")
-        Singledata<-read.csv(Single.file,header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=".")
+        ### cat("\nEnter Data file name(without file extension of.csv)\n")
+        ### Single.file <-readline()
+        ### Single.file<-paste(Single.file,".csv",sep="")
+        cnames<-c("Time","Assay")
+        Singledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=";",dec=".")
         Singledata<-edit(Singledata)
         Singledata<- na.omit(Singledata)
         cat("\n\n")
@@ -71,11 +71,11 @@ if (pick == 1){
 else {
   if (pick == 4){
   cat("\n\n")
-        cat("\nEnter Data file name(without file extension of.csv)\n")
-        Single.file <-readline()
-        Single.file<-paste(Single.file,".csv",sep="")
-        cnames<-c("time","assay (%)")
-        Singledata<-read.csv(Single.file,header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=",")
+        ### cat("\nEnter Data file name(without file extension of.csv)\n")
+        ### Single.file <-readline()
+        ### Single.file<-paste(Single.file,".csv",sep="")
+        cnames<-c("Time","Assay")
+        Singledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=",")
         Singledata<-edit(Singledata)
         Singledata<- na.omit(Singledata)
         cat("\n\n")
@@ -89,11 +89,11 @@ else {
 else {
   if (pick == 5){
   cat("\n\n")
-        cat("\nEnter Data file name(without file extension of.csv)\n")
-        Single.file <-readline()
-        Single.file<-paste(Single.file,".csv",sep="")
-        cnames<-c("time","assay (%)")
-        Singledata<-read.csv(Single.file,header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=".")
+        ### cat("\nEnter Data file name(without file extension of.csv)\n")
+        ### Single.file <-readline()
+        ### Single.file<-paste(Single.file,".csv",sep="")
+        cnames<-c("Time","Assay")
+        Singledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=" ",dec=".")
         Singledata<-edit(Singledata)
         Singledata<- na.omit(Singledata)
         cat("\n\n")
@@ -108,11 +108,11 @@ else {
 else {
   if (pick == 6){
   cat("\n\n")
-        cat("\nEnter Data file name(without file extension of.csv)\n")
-        Single.file <-readline()
-        Single.file<-paste(Single.file,".csv",sep="")
-        cnames<-c("time","assay (%)")
-        Singledata<-read.csv(Single.file,header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=",")
+        ### cat("\nEnter Data file name(without file extension of.csv)\n")
+        ### Single.file <-readline()
+        ### Single.file<-paste(Single.file,".csv",sep="")
+        cnames<-c("Time","Assay")
+        Singledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=",")
         Singledata<-edit(Singledata)
         Singledata<- na.omit(Singledata)
         cat("\n\n")
@@ -126,11 +126,11 @@ else {
 else {
   if (pick == 7){
   cat("\n\n")
-        cat("\nEnter Data file name(without file extension of.csv)\n")
-        Single.file <-readline()
-        Single.file<-paste(Single.file,".csv",sep="")
-        cnames<-c("time","assay (%)")
-        Singledata<-read.csv(Single.file,header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=".")
+        ### cat("\nEnter Data file name(without file extension of.csv)\n")
+        ### Single.file <-readline()
+        ### Single.file<-paste(Single.file,".csv",sep="")
+        cnames<-c("Time","Assay")
+        Singledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep="\t",dec=".")
         Singledata<-edit(Singledata)
         Singledata<- na.omit(Singledata)
         cat("\n\n")
@@ -144,11 +144,11 @@ else {
 else {
   if (pick == 8){
   cat("\n\n")
-        cat("\nEnter Data file name(without file extension of.csv)\n")
-        Single.file <-readline()
-        Single.file<-paste(Single.file,".csv",sep="")
-        cnames<-c("time","assay (%)")
-        Singledata<-read.csv(Single.file,header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=",")
+        ### cat("\nEnter Data file name(without file extension of.csv)\n")
+        ### Single.file <-readline()
+        ### Single.file<-paste(Single.file,".csv",sep="")
+        cnames<-c("Time","Assay")
+        Singledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=",")
         Singledata<-edit(Singledata)
         Singledata<- na.omit(Singledata)
         cat("\n\n")
@@ -162,11 +162,11 @@ else {
 else {
   if (pick == 9){
   cat("\n\n")
-        cat("\nEnter Data file name(without file extension of.csv)\n")
-        Single.file <-readline()
-        Single.file<-paste(Single.file,".csv",sep="")
-        cnames<-c("time","assay (%)")
-        Singledata<-read.csv(Single.file,header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=".")
+        ### cat("\nEnter Data file name(without file extension of.csv)\n")
+        ### Single.file <-readline()
+        ### Single.file<-paste(Single.file,".csv",sep="")
+        cnames<-c("Time","Assay")
+        Singledata<-read.csv(file.choose(),header=TRUE,row.names=NULL,col.names=cnames, sep=":",dec=".")
         Singledata<-edit(Singledata)
         Singledata<- na.omit(Singledata)
         cat("\n\n")
